@@ -5,9 +5,8 @@ monobit - tools for working with monochrome bitmap fonts
 licence: https://opensource.org/licenses/MIT
 """
 
-# we need at least Python 3.7
 import sys as _sys
-assert _sys.version_info >= (3, 7)
+assert _sys.version_info >= (3, 9)
 
 from .constants import VERSION as __version__
 from .pack import Pack, operations as _pack_operations
@@ -18,6 +17,7 @@ from .magic import FileFormatError
 from .encoding import charmaps, encoder
 from .taggers import tagmaps
 from .renderer import render
+from .chart import chart
 from .labels import Char, Codepoint, Tag
 
 # ensure plugins get registered
