@@ -13,7 +13,7 @@ import logging
 
 from ...binary import align
 from ...struct import little_endian as le
-from ...streams import FileFormatError
+from ...magic import FileFormatError
 from .mz import ALIGN_SHIFT
 from .fnt import create_fnt
 
@@ -140,7 +140,7 @@ _MODULE_NAME = b'FONTLIB'
 # .FON (NE executable) file reader
 
 def read_ne(instream, all_type_ids):
-    """Read font resources from an NE-format FON file."""
+    """Read font resources from a Windows NE-format FON file."""
     # stream pointer is at the start of the NE header
     # but some offsets in the file are given from the MZ header before that
     ne_offset = instream.tell()
@@ -148,8 +148,16 @@ def read_ne(instream, all_type_ids):
     data = instream.read()
     header = _NE_HEADER.from_bytes(data, ne_offset)
     logging.debug(header)
-    if header.ne_exetyp not in (2, 4):
-        logging.warning('This is not a Windows NE file.')
+    if header.ne_exetyp not in (0, 2, 4):
+        # 0 unknown (but used by Windows 1.0)
+        # 1 OS/2
+        # 2 Windows
+        # 3 European MS_DOS 4.x
+        # 4 Windows 386
+        # 5 Borland Operating System Services
+        logging.warning(
+            'Not a Windows NE file: EXE type %d', header.ne_exetyp
+        )
     # parse the first elements of the resource table
     res_table = _RES_TABLE_HEAD.from_bytes(data, ne_offset + header.ne_rsrctab)
     logging.debug(res_table)
@@ -182,16 +190,12 @@ def read_ne(instream, all_type_ids):
                     'Reading resource of type %d at offset %x [%x]',
                     type_info.rtTypeID, start, name_info.rnOffset
                 )
-                try:
-                    resources.append(data[start : start+size])
-                except ValueError as e:
-                    # e.g. not a bitmap font
-                    # don't raise exception so we can continue with other resources
-                    logging.error('Failed to read font resource at {:x}: {}'.format(start, e))
-            logging.debug(
-                'Skipping resource of type %d at offset %x [%x]',
-                type_info.rtTypeID, start, name_info.rnOffset
-            )
+                resources.append(data[start : start+size])
+            else:
+                logging.debug(
+                    'Skipping resource of type %d at offset %x [%x]',
+                    type_info.rtTypeID, start, name_info.rnOffset
+                )
         # rtResourceCount * 12
         ti_offset += type_info_head.size + nameinfo_array.size
     return resources
